Models class sealed

Implementers

Properties

apiKey → String?
API key for the AI service, if required.
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
Headers to include in the HTTP request.
no setter
instruction → String
final
model → String?
The model to use for AI completion, if applicable.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
API Url
no setter

Methods

buildRequest(String code) → Map<String, dynamic>
completionResponse(String code) → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseParser(dynamic response) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited