Sonar class

Sonar AI model implementation.

Inheritance

Constructors

Sonar({required String apiKey, required String model})

Properties

apiKey → String
API key for the AI service, if required.
final
baseUrl → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
Headers to include in the HTTP request.
no setterinherited
instruction → String
finalinherited
model → String
The model to use for AI completion, if applicable.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
API Url
no setterinherited

Methods

buildRequest(String code) → Map<String, dynamic>
inherited
completionResponse(String code) → Future<String>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseParser(dynamic response) → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited