LspConfig class sealed

Implementers

Properties

disableError → bool
Whether to disable errors from the LSP server.
final
disableWarning → bool
Whether to disable warnings from the LSP server.
final
filePath → String
The file path of the document to be processed by the LSP.
final
hashCode → int
The hash code for this object.
no setterinherited
languageId → String
The language ID of the language.
final
responses → Stream<Map<String, dynamic>>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workspacePath → String
The workspace path of the document to be processed by the LSP.
final

Methods

closeDocument() → Future<void>
Updates the document in the LSP server if there is any change. /// This method is used internally by the CodeCrafter widget and calling it directly is not recommended.
dispose() → void
getCompletions(int line, int character) → Future<List<LspCompletion>>
This method is used to get completions at a specific position in the document.
getDefinition(int line, int character) → Future<String>
getHover(int line, int character) → Future<String>
This method is used to get details at a specific position in the document.
getReferences(int line, int character) → Future<List>
initialize() → Future<void>
This method is used to initialize the LSP server.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDocument() → Future<void>
Opens the document in the LSP server.
toString() → String
A string representation of this object.
inherited
updateDocument(String content) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited