GutterStyle class

This class provides styling options for the Gutter.

Constructors

GutterStyle({TextStyle? lineNumberStyle, double? gutterWidth, IconData breakpointIcon = Icons.circle, IconData unfilledBreakpointIcon = Icons.circle_outlined, IconData foldedIcon = Icons.chevron_right_outlined, IconData unfoldedIcon = Icons.keyboard_arrow_down_outlined, Color? dividerColor, double? dividerThickness, double? breakpointSize, double? foldingIconSize, Color breakpointColor = Colors.red, Color unfilledBreakpointColor = Colors.transparent, Color foldedIconColor = Colors.grey, Color unfoldedIconColor = Colors.grey})

Properties

breakpointColor → Color
The color for the breakpoint icon in the gutter. Defaults to Colors.red.
final
breakpointIcon → IconData
The icons used for breakpoints and folding indicators in the gutter.
final
breakpointSize → double?
The size of the breakpoint icon in the gutter. Defaults to (widget?.textStyle?.fontSize ?? 14) * 0.6.
final
dividerColor → Color?
Color of the vertical divider line between gutter and editor.
final
dividerThickness → double?
The thickness of the vertical divider between gutter and editor.
final
foldedIcon → IconData
The icon used for the unfolded line folding indicator in the gutter.
final
foldedIconColor → Color
The color for the folded line folding indicator icon in the gutter. Defaults to Colors.grey.
final
foldingIconSize → double?
The size of the folding icon in the gutter. Defaults to (widget?.textStyle?.fontSize ?? 14) * 1.2.
final
gutterWidth → double?
The width of the gutter. Dynamic by default, which means it can adapt best width based on line number. So recommended to leave it null.
final
hashCode → int
The hash code for this object.
no setterinherited
lineNumberStyle → TextStyle?
The style for line numbers in the gutter. Expected to be a TextStyle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unfilledBreakpointColor → Color
The color for the unfilled breakpoint icon in the gutter. Defaults to Colors.transparent.
final
unfilledBreakpointIcon → IconData
The icon used for unfilled breakpoints in the gutter.
final
unfoldedIcon → IconData
The icon used for the folded line folding indicator in the gutter.
final
unfoldedIconColor → Color
The color for the unfolded line folding indicator icon in the gutter. Defaults to Colors.grey.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited