Shared class

This class is a singleton that holds shared state and configurations for the application. It is used internally by the CodeCrafter widget and other components to maintain a consistent state across the application. It includes properties for AI responses, gutter width, theme styles, text styles, tab size, diagnostics, and more.

Constructors

Shared()
factory

Properties

aiOverlayStyle ↔ TextStyle?
getter/setter pair
aiResponse ↔ String?
getter/setter pair
controller ↔ CodeCrafterController
getter/setter pair
diagnostics ↔ List<LspErrors>
getter/setter pair
enableRulerLines ↔ bool
getter/setter pair
gutterWidth ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastCursorPosition ↔ int?
getter/setter pair
lineStates ↔ ValueNotifier<List<LineState>>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabSize ↔ int
getter/setter pair
textStyle ↔ TextStyle?
getter/setter pair
theme ↔ Map<String, TextStyle>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited