EditorField class

This class is used to define the properties of the CodeCrafter field. It includes the same properties as the TextField widget,. If provided it will be passed to the underlying TextField of the CodeCrafter widget.

Constructors

EditorField({Key? key, void onChanged(String)?, void onTap()?, void onEditingComplete()?, void onSubmitted(String)?, void onTapOutside(PointerDownEvent)?, TextInputType? keyboardType, List<TextInputFormatter>? inputFormatters, InputDecoration? decoration, bool? obscureText, bool? enableSuggestions, TextCapitalization? textCapitalization, bool? autocorrect, TextInputAction? textInputAction, TextAlign? textAlign, TextAlignVertical? textAlignVertical, TextStyle? style, TextDirection? textDirection, bool? expands, int? maxLines, int? minLines, int? maxLength, MaxLengthEnforcement? maxLengthEnforcement, bool? showCursor, double? cursorWidth, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, ScrollPhysics? scrollPhysics, ScrollController? scrollController, SmartQuotesType? smartQuotesType, SmartDashesType? smartDashesType, Iterable<String>? autofillHints, String? restorationId, MouseCursor? mouseCursor, EditableTextContextMenuBuilder? contextMenuBuilder})

Properties

autocorrect → bool?
final
autofillHints → Iterable<String>?
final
contextMenuBuilder → EditableTextContextMenuBuilder?
final
cursorColor → Color?
final
cursorHeight → double?
final
cursorRadius → Radius?
final
cursorWidth → double?
final
decoration → InputDecoration?
final
enableInteractiveSelection → bool?
final
enableSuggestions → bool?
final
expands → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
inputFormatters → List<TextInputFormatter>?
final
key ↔ Key?
getter/setter pair
keyboardType → TextInputType?
final
maxLength → int?
final
maxLengthEnforcement → MaxLengthEnforcement?
final
maxLines → int?
final
minLines → int?
final
mouseCursor → MouseCursor?
final
obscureText → bool?
final
onChanged → void Function(String)?
final
onEditingComplete → void Function()?
final
onSubmitted → void Function(String)?
final
onTap → void Function()?
final
onTapOutside → void Function(PointerDownEvent)?
final
restorationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController?
final
scrollPhysics → ScrollPhysics?
final
selectionControls → TextSelectionControls?
final
showCursor → bool?
final
smartDashesType → SmartDashesType?
final
smartQuotesType → SmartQuotesType?
final
style → TextStyle?
final
textAlign → TextAlign?
final
textAlignVertical → TextAlignVertical?
final
textCapitalization → TextCapitalization?
final
textDirection → TextDirection?
final
textInputAction → TextInputAction?
final

Methods

build({Key? key, required TextEditingController controller, required FocusNode focusNode, required bool autofocus, required bool readOnly, required TextStyle? fallbackStyle, required Color? fallbackCursorColor, required Map<String, TextStyle>? editorTheme}) → TextField
copyWith({Key? key, void onChanged(String)?, dynamic onSubmitted, void onTap()?, dynamic onEditingComplete, void onTapOutside(PointerDownEvent)?, TextInputType? keyboardType, TextInputAction? textInputAction, List<TextInputFormatter>? inputFormatters, TextCapitalization? textCapitalization, bool? obscureText, dynamic enableSuggestions, dynamic autocorrect, InputDecoration? decoration, TextAlign? textAlign, TextStyle? style, TextDirection? textDirection, TextAlignVertical? textAlignVertical, bool? expands, int? maxLines, dynamic minLines, dynamic maxLength, MaxLengthEnforcement? maxLengthEnforcement, bool? showCursor, double? cursorWidth, dynamic cursorHeight, Radius? cursorRadius, Color? cursorColor, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, ScrollPhysics? scrollPhysics, ScrollController? scrollController, SmartQuotesType? smartQuotesType, SmartDashesType? smartDashesType, Iterable<String>? autofillHints, String? restorationId, MouseCursor? mouseCursor, EditableTextContextMenuBuilder? contextMenuBuilder}) → EditorField
Creates a copy of this EditorField with the given fields replaced by the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited