LineState class

This class is used to represent the state of a line in the editor. It is used internally by the CodeCrafter widget to manage line states such as breakpoints and folding ranges.

Constructors

LineState({required int lineNumber, bool hasBreakpoint = false})

Properties

foldRange ↔ FoldRange?
getter/setter pair
hasBreakpoint → bool
final
hashCode → int
The hash code for this object.
no setterinherited
lineNumber → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited